@@ -12,7 +12,7 @@
 # Description:
 # Use Shell to do additional jobs after installation is done, mainly for upgrading.
 #
-echo "POST INSTALLATION: Remove old subsystem folder.."
+echo "POST INSTALLATION: Do something additional after installation.."
 
 SUB_SYSTEM_PATH=/opt/tandbergtv/cms/workflow/plugins/subsystems
 
@@ -30,20 +30,13 @@ do
 	fi
 done
 
-CMS_CLUSER_PROP=/opt/tandbergtv/cms/conf/workflow/cluster.properties
-PREPACK_CLUSER_PROP=/opt/tandbergtv/cms/conf/prepack/cluster.properties
-PREPACK_CLUSER_PROP_FOLDER=/opt/tandbergtv/cms/conf/prepack
-if [ -f "$CMS_CLUSER_PROP" ] 
+CF_DATATYPE_MAPPING_DAT=/opt/tandbergtv/cms/plugins/content/com.tandbergtv.metadata/resources/cfDataTypeMapping.dat
+if [ -f "$CF_DATATYPE_MAPPING_DAT" ] 
 then
-    echo "copying $CMS_CLUSER_PROP to $PREPACK_CLUSER_PROP"
-    mkdir -p $PREPACK_CLUSER_PROP_FOLDER
-    cp $CMS_CLUSER_PROP $PREPACK_CLUSER_PROP
-    chmod 755 $PREPACK_CLUSER_PROP
-
-    sed -i -e 's/workflow/prepack/g' $PREPACK_CLUSER_PROP
+    echo "remove $CF_DATATYPE_MAPPING_DAT"
+    rm -rf $CF_DATATYPE_MAPPING_DAT
 else
-    echo "$CMS_CLUSER_PROP does not exists!"
+    echo "$CF_DATATYPE_MAPPING_DAT does not exists!"
 fi
 
-
 echo "POST INSTALLATION: done.."
\ No newline at end of file
