@@ -32,19 +32,11 @@ else
    grep LOG /etc/bashrc > /dev/null || echo export LOG=/opt/tandbergtv/cms/log/jboss.log >> /etc/bashrc
 fi
 
-PRE_CONFIGURED_FILE=$1
-
 cd pysetup
 sh ./pysetup.sh $isCMS4_0
 source /etc/bashrc
 cd ..
-if [ -z "$PRE_CONFIGURED_FILE" ]
-then
-	echo "No pre-configured selection file passed in.  User will be prompted to select components directly"
-	python ./scripts/install.pyc -i install_sysInfo.json
-else
-	python ./scripts/install.pyc -i install_sysInfo.json -p $PRE_CONFIGURED_FILE
-fi
+python ./scripts/install.pyc -i install_sysInfo.json $@
 
 cd pysetup
 sh ./pyunstall.sh $isCMS4_0
