@@ -41,14 +41,7 @@ cd ..
 
 grep LOG /etc/bashrc > /dev/null || echo export LOG=/opt/tandbergtv/cms/log/jboss.log >> /etc/bashrc
 
-
-if [ -z "$PRE_CONFIGURED_FILE" ]
-then
-	echo "No pre-configured selection file passed in.  User will be prompted to select components directly"
-	python ./scripts/install.pyc -i install_sysInfo.json -m UPGRADE
-else
-	python ./scripts/install.pyc -i install_sysInfo.json -p $PRE_CONFIGURED_FILE -m UPGRADE
-fi
+python ./scripts/install.pyc -i install_sysInfo.json -m UPGRADE $@
 
 cd pysetup
 sh ./pyunstall.sh $isCMS4_0
\ No newline at end of file
